<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lt">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../forms/aboutdialog.ui" line="14"/>
        <source>About Qmmp</source>
        <translation>Apie Qmmp</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="40"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="96"/>
        <source>License Agreement</source>
        <translation>Licenzija</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="54"/>
        <source>Authors</source>
        <translation>Autoriai</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="82"/>
        <source>Thanks To</source>
        <translation>Dėkojame</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="61"/>
        <source>:/txt/authors_en.txt</source>
        <translation>:/txt/authors_lt.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="62"/>
        <source>:/txt/thanks_en.txt</source>
        <translation>:/txt/thanks_lt.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>Qt-based Multimedia Player (Qmmp)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Version:</source>
        <translation>Versija:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="83"/>
        <source>:txt/description_en.txt</source>
        <translation>:txt/description_lt.txt</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Input plugins:</source>
        <translation>Įeinantys:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Output plugins:</source>
        <translation>Išeinantys:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>Visual plugins:</source>
        <translation>Vizualizacijos:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="111"/>
        <source>Effect plugins:</source>
        <translation>Efektai:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="120"/>
        <source>General plugins:</source>
        <translation>Bendriniai įskiepiai:</translation>
    </message>
    <message>
        <location filename="../forms/aboutdialog.ui" line="68"/>
        <source>Translators</source>
        <translation>Vertėjai</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>:/txt/translators_en.txt</source>
        <translation>:/txt/translators_lt.txt</translation>
    </message>
</context>
<context>
    <name>ActionManager</name>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>&amp;Play</source>
        <translation>&amp;Groti</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="37"/>
        <source>X</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pristabdyti</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="38"/>
        <source>C</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>&amp;Stop</source>
        <translation>&amp;Sustabdyti</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="39"/>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>&amp;Previous</source>
        <translation>&amp;Ankstesnis</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="40"/>
        <source>Z</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>&amp;Next</source>
        <translation>&amp;Sekantis</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="41"/>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>&amp;Play/Pause</source>
        <translation>&amp;Groti/Pristabdyti</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="42"/>
        <source>Space</source>
        <translation>Tarpas</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>&amp;Jump to File</source>
        <translation>&amp;Peršokti prie failo</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="43"/>
        <source>J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>&amp;Repeat Playlist</source>
        <translation>&amp;Kartoti grojaraštį</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="44"/>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>&amp;Repeat Track</source>
        <translation>&amp;Kartoti takelį</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="45"/>
        <source>Ctrl+R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>&amp;Shuffle</source>
        <translation>&amp;Sumaišyti</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="46"/>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="47"/>
        <source>&amp;No Playlist Advance</source>
        <translatorcomment>?????</translatorcomment>
        <translation>&amp;Nesislinkti grojaraščiu</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="48"/>
        <source>Ctrl+N</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="49"/>
        <source>&amp;Stop After Selected</source>
        <translation>&amp;Stabdyti po pasirinkto</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="50"/>
        <source>Ctrl+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>&amp;Clear Queue</source>
        <translation>&amp;Išvalyti eilę</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="51"/>
        <source>Alt+Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Show Playlist</source>
        <translation>Rodyti grojaraštį</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="53"/>
        <source>Alt+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Show Equalizer</source>
        <translation>Rodyti glotintuvą</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="54"/>
        <source>Alt+G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="55"/>
        <source>Always on Top</source>
        <translation>Visada viršuje</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="56"/>
        <source>Put on All Workspaces</source>
        <translation>Įkelti į visus darbastalius</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Double Size</source>
        <translation>Dvigubas dydis</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="57"/>
        <source>Meta+D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>&amp;Add File</source>
        <translation>&amp;Pridėti bylą</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="59"/>
        <source>F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>&amp;Add Directory</source>
        <translation>&amp;Pridėti aplanką</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="60"/>
        <source>D</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>&amp;Add Url</source>
        <translation>&amp;Pridėti interneto adresą</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="61"/>
        <source>U</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="62"/>
        <source>&amp;Remove Selected</source>
        <translation>&amp;Pašalinti pasirinktus</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="63"/>
        <source>Del</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="64"/>
        <source>&amp;Remove All</source>
        <translation>&amp;Pašalinti visus</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="65"/>
        <source>&amp;Remove Unselected</source>
        <translation>&amp;Pašalinti NEpasirinktus</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="67"/>
        <source>Remove unavailable files</source>
        <translation>Pašalinti neesamas bylas</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="69"/>
        <source>Remove duplicates</source>
        <translation>Pašalinti besidubliuojančius pavadinimus</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>&amp;Queue Toggle</source>
        <translation>&amp;Įtraukti į eilę</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="70"/>
        <source>Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="71"/>
        <source>Invert Selection</source>
        <translation>Apverstinis pasirinkimas</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="72"/>
        <source>&amp;Select None</source>
        <translation>&amp;Nepasirinkti nei vieno</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="73"/>
        <source>&amp;Select All</source>
        <translation>&amp;Pasirinkti visus</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="74"/>
        <source>Ctrl+A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>&amp;View Track Details</source>
        <translation>&amp;Takelio informacija</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="75"/>
        <source>Alt+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>&amp;New List</source>
        <translation>&amp;Naujas sąrašas</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="77"/>
        <source>Ctrl+T</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>&amp;Delete List</source>
        <translation>&amp;Pašalinti sąrašą</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="78"/>
        <source>Ctrl+W</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>&amp;Load List</source>
        <translation>&amp;Įkelti sąrašą</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="79"/>
        <source>O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>&amp;Save List</source>
        <translation>&amp;Išsaugoti sąrašą</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="80"/>
        <source>Shift+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="81"/>
        <source>&amp;Select Next Playlist</source>
        <translation>&amp;Pasirinkti sekantį grojaraštį</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="82"/>
        <source>Ctrl+PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="83"/>
        <source>&amp;Select Previous Playlist</source>
        <translation>&amp;Pasirinkti ankstesnį grojaraštį</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="84"/>
        <source>Ctrl+PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="85"/>
        <source>&amp;Show Playlists</source>
        <translation>&amp;Rodyti grojaraščius</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="86"/>
        <source>P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>&amp;Settings</source>
        <translation>&amp;Nustatymai</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>Ctrl+P</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>&amp;About Qt</source>
        <translation>&amp;Apie Qt</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>&amp;Exit</source>
        <translation>&amp;Išeiti</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Ctrl+Q</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddUrlDialog</name>
    <message>
        <location filename="../addurldialog.cpp" line="117"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="13"/>
        <source>Enter URL to add</source>
        <translation>Įveskite adresą</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="51"/>
        <source>&amp;Add</source>
        <translation>&amp;Pridėti</translation>
    </message>
    <message>
        <location filename="../forms/addurldialog.ui" line="58"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Atšaukti</translation>
    </message>
</context>
<context>
    <name>BuiltinCommandLineOption</name>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="61"/>
        <source>Skip forward in playlist</source>
        <translation>Eiti prie sekančio elemento</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="62"/>
        <source>Skip backwards in playlist</source>
        <translation>Eiti prie ankstesnio elemento</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="55"/>
        <source>Start playing current song</source>
        <translation>Groti dainą</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="54"/>
        <source>Don&apos;t clear the playlist</source>
        <translation>Neišvalyti sąrašo</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="56"/>
        <source>Pause current song</source>
        <translation>Pristabdyti dainą</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="57"/>
        <source>Pause if playing, play otherwise</source>
        <translation>Pristabdyti/Groti</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="58"/>
        <source>Stop current song</source>
        <translation>Sustabdyti dainą</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="59"/>
        <source>Display Jump to File dialog</source>
        <translation>Parodyti langą bylos pasirinkimui</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="60"/>
        <source>Set playback volume (example: qmmp --volume 20)</source>
        <translation>Nustatyti grojimo garsą (pvz: qmmp --volume 20)</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="63"/>
        <source>Show/hide application</source>
        <translation>Parodyti/Slėpti programą</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="64"/>
        <source>Display Add File dialog</source>
        <translation>Parodyti langą bylų pridėjimui</translation>
    </message>
    <message>
        <location filename="../builtincommandlineoption.cpp" line="65"/>
        <source>Display Add Directory dialog</source>
        <translation>Parodyti langą aplanko pridėjimui</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../forms/configdialog.ui" line="735"/>
        <source>Description</source>
        <translation>Aprašymas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="740"/>
        <source>Filename</source>
        <translation>Bylos pavadinimas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="429"/>
        <source>Artist</source>
        <translation>Atlikėjas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="75"/>
        <location filename="../configdialog.cpp" line="430"/>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="74"/>
        <source>Track</source>
        <translation>Takelis</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="76"/>
        <source>Disabled</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="244"/>
        <source>Transports</source>
        <translation>Transportas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="255"/>
        <source>Decoders</source>
        <translation>Dekoderiai</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="265"/>
        <source>Engines</source>
        <translation>Varikliai</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="372"/>
        <source>Misc</source>
        <translation>Įvairūs</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="431"/>
        <source>Title</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="432"/>
        <source>Track number</source>
        <translation>Takelio numeris</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="433"/>
        <source>Two-digit track number</source>
        <translation>Dviejų skaičių takelio numeris</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="437"/>
        <source>Disc number</source>
        <translation>Disko numeris</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="441"/>
        <source>Condition</source>
        <translation>Būklė</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="436"/>
        <source>Composer</source>
        <translation>Autorius</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="438"/>
        <source>File name</source>
        <translation>Bylos pavadinimas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="439"/>
        <source>File path</source>
        <translation>Bylos kelias</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="434"/>
        <source>Genre</source>
        <translation>Žanras</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="440"/>
        <source>Year</source>
        <translation>Metai</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="435"/>
        <source>Comment</source>
        <translation>Komentaras</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="14"/>
        <source>Qmmp Settings</source>
        <translation>Qmmp nustatymai</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="184"/>
        <source>Skins</source>
        <translation>Temos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="291"/>
        <source>Fonts</source>
        <translation>Šriftai</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="309"/>
        <source>Player:</source>
        <translation>Grotuvas:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="357"/>
        <source>Playlist:</source>
        <translation>Gojaraštis:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="331"/>
        <location filename="../forms/configdialog.ui" line="379"/>
        <source>???</source>
        <translation>???</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="338"/>
        <location filename="../forms/configdialog.ui" line="386"/>
        <location filename="../forms/configdialog.ui" line="552"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="511"/>
        <source>Metadata</source>
        <translation>Meta duomenys</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="523"/>
        <source>Load metadata from files</source>
        <translation>Įkelti metaduomenis iš bylų</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="533"/>
        <source>Song Display</source>
        <translation>Dainų sąrašas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="539"/>
        <source>Title format:</source>
        <translation>Pavadinimo formatas:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="686"/>
        <location filename="../forms/configdialog.ui" line="1153"/>
        <source>Preferences</source>
        <translation>Nustatymai</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="699"/>
        <location filename="../forms/configdialog.ui" line="761"/>
        <location filename="../forms/configdialog.ui" line="1166"/>
        <source>Information</source>
        <translation>Informacija</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="98"/>
        <source>Appearance</source>
        <translation>Išvaizda</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="107"/>
        <location filename="../forms/configdialog.ui" line="463"/>
        <location filename="../configdialog.cpp" line="366"/>
        <source>Playlist</source>
        <translation>Grojaraštis</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="116"/>
        <source>Plugins</source>
        <translation>Įskiepiai</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="125"/>
        <source>Advanced</source>
        <translation>Papildomi</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1238"/>
        <source>16-bit output</source>
        <translation>16 bitų išvestis</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="209"/>
        <source>Archived skin</source>
        <translation>Suspausta tema</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="231"/>
        <source>Unarchived skin</source>
        <translation>Išskleista tema</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="134"/>
        <source>Connectivity</source>
        <translation>Tinklas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="285"/>
        <source>Visualization</source>
        <translation>Vizualizacija</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="275"/>
        <source>Effects</source>
        <translation>Efektai</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="295"/>
        <source>General</source>
        <translation>Bendri</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="752"/>
        <source>File Dialog</source>
        <translation>Pasirinkimo langas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="143"/>
        <location filename="../forms/configdialog.ui" line="1131"/>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1001"/>
        <source>Replay Gain</source>
        <translatorcomment>Neįsivaizduoju kaip verst</translatorcomment>
        <translation>Replay Gain</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="249"/>
        <source>Miscellaneous</source>
        <translation>Kiti</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="393"/>
        <source>Use bitmap font if available</source>
        <translation>Naudoti bitmap šriftą, jei įmanoma</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="275"/>
        <source>Use skin cursors</source>
        <translation>Naudoti temos kursorių</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="580"/>
        <source>Show song numbers</source>
        <translation>Rodyti takelių numerius</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="587"/>
        <source>Show playlists</source>
        <translation>Rodyti grojaraščius</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="596"/>
        <source>Show popup information</source>
        <translation>Rodyti iššokančią informaciją</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1007"/>
        <source>Replay Gain mode:</source>
        <translation>Replay Gain metodas:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1024"/>
        <source>Preamp:</source>
        <translation>Išankstinis stiprinimas:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1056"/>
        <location filename="../forms/configdialog.ui" line="1101"/>
        <source>dB</source>
        <translation>dB</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1069"/>
        <source>Default gain:</source>
        <translation>Stiprinimas pagal nutylėjima:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1121"/>
        <source>Use  peak info to prevent clipping</source>
        <translation>Naudoti pikų informaciją trūkinėjimo išvengimui</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1137"/>
        <source>Output:</source>
        <translation>Išvestis</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1189"/>
        <source>Buffer size:</source>
        <translation>Buferio dydis:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1202"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1231"/>
        <source>Use software volume control</source>
        <translation>Naudoti programinį garso valdymą</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="255"/>
        <location filename="../configdialog.cpp" line="360"/>
        <source>View</source>
        <translation>Rodyti</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="152"/>
        <source>Shortcuts</source>
        <translation>Santrumpos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="261"/>
        <source>Hide on close</source>
        <translation>Paslėpti išjungus</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="268"/>
        <source>Start hidden</source>
        <translation>Įjungti paslėptą</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="606"/>
        <source>Edit template</source>
        <translation>Taisyti šabloną</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="628"/>
        <source>Show anchor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="638"/>
        <source>Align song numbers</source>
        <translation>Lygiuoti dainų numerius</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="784"/>
        <source>Cover Image Retrieve</source>
        <translation>Parsiųsti cd viršelį</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="790"/>
        <source>Use separate image files</source>
        <translation>Naudoti atskiras paveiksliukų bylas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="800"/>
        <source>Include files:</source>
        <translation>Įtraukti bylas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="810"/>
        <source>Exclude files:</source>
        <translation>Išskirti bylas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="822"/>
        <source>Recursive search depth:</source>
        <translation>Rekursinės paieškos gylis</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="867"/>
        <location filename="../configdialog.cpp" line="354"/>
        <source>Playback</source>
        <translation>Grojimas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="873"/>
        <source>Continue playback on startup</source>
        <translation>Tęsti grojimą įjungus</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="899"/>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="911"/>
        <source>Enable proxy usage</source>
        <translation>Įjungti proxy palaikymą </translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="918"/>
        <source>Proxy host name:</source>
        <translation>Proxy serveris:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="931"/>
        <source>Proxy port:</source>
        <translation>Proxy portas:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="944"/>
        <source>Use authentication with proxy</source>
        <translation>Naudoti proxy autentifikavimą</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="951"/>
        <source>Proxy user name:</source>
        <translation>Proxy vartotojo vardas:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="964"/>
        <source>Proxy password:</source>
        <translation>Proxy slaptažodis:</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1272"/>
        <source>Action</source>
        <translation>Veiksmas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1277"/>
        <source>Shortcut</source>
        <translation>Trumpinys</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="1285"/>
        <source>Change shortcut...</source>
        <translation>Keisti trumpinį...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="559"/>
        <source>Convert underscores to blanks</source>
        <translation>Paversti brūkšnius į tarpus</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="566"/>
        <source>Convert %20 to blanks</source>
        <translation>Paversti %20 į tarpus</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="524"/>
        <source>Select Skin Files</source>
        <translation>Pasirinkti temų bylas</translation>
    </message>
    <message>
        <location filename="../configdialog.cpp" line="525"/>
        <source>Skin files</source>
        <translation>Temų bylos</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="215"/>
        <source>Add...</source>
        <translation>Pridėti...</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="228"/>
        <source>Refresh</source>
        <translation>Atnaujinti</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="573"/>
        <source>Show protocol</source>
        <translation>Rodyti bylos galūnę</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="403"/>
        <source>Transparency</source>
        <translation>Permatomumas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="409"/>
        <source>Main window</source>
        <translation>Pagrindinis langas</translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="432"/>
        <location filename="../forms/configdialog.ui" line="456"/>
        <location filename="../forms/configdialog.ui" line="480"/>
        <source>0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/configdialog.ui" line="439"/>
        <source>Equalizer</source>
        <translation>Glodintuvas</translation>
    </message>
</context>
<context>
    <name>EqWidget</name>
    <message>
        <location filename="../eqwidget.cpp" line="154"/>
        <location filename="../eqwidget.cpp" line="177"/>
        <source>preset</source>
        <translation>Nustatymas</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="261"/>
        <source>&amp;Load/Delete</source>
        <translation>&amp;Įkelti/Pašalinti</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="263"/>
        <source>&amp;Save Preset</source>
        <translation>&amp;Išsaugoti nustatymus</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="265"/>
        <source>&amp;Save Auto-load Preset</source>
        <translation>&amp;Išsaugoti auto-nustatymą</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="270"/>
        <source>&amp;Clear</source>
        <translation>&amp;išvalyti</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="299"/>
        <source>Saving Preset</source>
        <translation>Išsaugojamas nustatymas</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="300"/>
        <source>Preset name:</source>
        <translation>Nustatymo pavadinimas:</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="301"/>
        <source>preset #</source>
        <translation>Nustatymas #</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="267"/>
        <source>&amp;Import</source>
        <translation>&amp;Importuoti</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="43"/>
        <source>Equalizer</source>
        <translation>Glotintuvas</translation>
    </message>
    <message>
        <location filename="../eqwidget.cpp" line="392"/>
        <source>Import Preset</source>
        <translation>Importuoti nustatymus</translation>
    </message>
</context>
<context>
    <name>JumpToTrackDialog</name>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="53"/>
        <source>Q</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="54"/>
        <source>J</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="55"/>
        <source>F5</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../jumptotrackdialog.cpp" line="84"/>
        <location filename="../jumptotrackdialog.cpp" line="135"/>
        <source>Unqueue</source>
        <translation>Pašalinti iš eilės</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="70"/>
        <location filename="../jumptotrackdialog.cpp" line="86"/>
        <location filename="../jumptotrackdialog.cpp" line="137"/>
        <source>Queue</source>
        <translation>Į eilę</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="14"/>
        <source>Jump To Track</source>
        <translation>Pereiti prie takelio</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="37"/>
        <source>Filter</source>
        <translation>Filtras</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="83"/>
        <source>Refresh</source>
        <translation>Atnaujinti</translation>
    </message>
    <message>
        <location filename="../forms/jumptotrackdialog.ui" line="96"/>
        <source>Jump To</source>
        <translation>Prereiti prie</translation>
    </message>
</context>
<context>
    <name>MainDisplay</name>
    <message>
        <location filename="../display.cpp" line="57"/>
        <source>Previous</source>
        <translation>Ankstesnis</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="61"/>
        <source>Play</source>
        <translation>Groti</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="64"/>
        <source>Pause</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="67"/>
        <source>Stop</source>
        <translation>Sustoti</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="70"/>
        <source>Next</source>
        <translation>Sekantis</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="73"/>
        <source>Add file</source>
        <translation>Pridėti bylą</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="80"/>
        <source>Equalizer</source>
        <translation>Glotintuvas</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="83"/>
        <source>Playlist</source>
        <translation>Grojaraštis</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="88"/>
        <source>Repeat playlist</source>
        <translation>Gartoti grojaraštį</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="91"/>
        <source>Shuffle</source>
        <translation>Atsitiktine tvarka</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="101"/>
        <source>Volume</source>
        <translation>Garsumas</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="107"/>
        <source>Balance</source>
        <translation>Balansas</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="296"/>
        <source>Volume: %1%</source>
        <translation>Garsas: %1%</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="300"/>
        <source>Balance: %1% right</source>
        <translation>Balansas: %1% dešinė</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="302"/>
        <source>Balance: %1% left</source>
        <translation>Balansas: %1% kairė</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="304"/>
        <source>Balance: center</source>
        <translation>Balansas: centras</translation>
    </message>
    <message>
        <location filename="../display.cpp" line="315"/>
        <source>Seek to: %1</source>
        <translation>Peršokti į: %1</translation>
    </message>
</context>
<context>
    <name>MainVisual</name>
    <message>
        <location filename="../mainvisual.cpp" line="280"/>
        <source>Visualization Mode</source>
        <translation>Vizualizacijos metodas</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="283"/>
        <source>Analyzer</source>
        <translation>Analizatorius</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="284"/>
        <source>Scope</source>
        <translation>Scope</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="285"/>
        <source>Off</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="292"/>
        <source>Analyzer Mode</source>
        <translation>Analizatoriaus metodas</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="295"/>
        <source>Normal</source>
        <translation>Įprastinis</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="296"/>
        <source>Fire</source>
        <translation>Ugnis</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="297"/>
        <source>Vertical Lines</source>
        <translation>Vertikalios linijos</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="298"/>
        <source>Lines</source>
        <translation>Linijos</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="299"/>
        <source>Bars</source>
        <translation>Bangos</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="312"/>
        <source>Peaks</source>
        <translation>Pikai</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="316"/>
        <source>Refresh Rate</source>
        <translation>Atnaujinimo dažnumas</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="319"/>
        <source>50 fps</source>
        <translation>50 kps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="320"/>
        <source>25 fps</source>
        <translation>25 kps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="321"/>
        <source>10 fps</source>
        <translation>10 kps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="322"/>
        <source>5 fps</source>
        <translation>5 kps</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="329"/>
        <source>Analyzer Falloff</source>
        <translation>Analyzer Falloff</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="332"/>
        <location filename="../mainvisual.cpp" line="346"/>
        <source>Slowest</source>
        <translation>Lėčiausias</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="333"/>
        <location filename="../mainvisual.cpp" line="347"/>
        <source>Slow</source>
        <translation>Lėtas</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="334"/>
        <location filename="../mainvisual.cpp" line="348"/>
        <source>Medium</source>
        <translation>Vidutinis</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="335"/>
        <location filename="../mainvisual.cpp" line="349"/>
        <source>Fast</source>
        <translation>Greitas</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="336"/>
        <location filename="../mainvisual.cpp" line="350"/>
        <source>Fastest</source>
        <translation>Greičiausias</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="343"/>
        <source>Peaks Falloff</source>
        <translation>Peaks Falloff</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="356"/>
        <source>Background</source>
        <translation>Fonas</translation>
    </message>
    <message>
        <location filename="../mainvisual.cpp" line="357"/>
        <source>Transparent</source>
        <translation>Permatomumas</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>Choose a directory</source>
        <translation>Pasirinkite aplanką</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Select one or more files to open</source>
        <translation>Pasirinkite vieną ar kelias bylas atvėrimui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>View</source>
        <translation>Rodyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="440"/>
        <source>Playlist</source>
        <translation>Grojaraštis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Open Playlist</source>
        <translation>Atverti grojaraštį</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="537"/>
        <source>Save Playlist</source>
        <translation>Išsaugoti grojaraštį</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="510"/>
        <location filename="../mainwindow.cpp" line="536"/>
        <source>Playlist Files</source>
        <translation>Grojaraščio bylos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>All Supported Bitstreams</source>
        <translation>Palaikomi bylų tipai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="460"/>
        <source>Tools</source>
        <translation>Įrankiai</translation>
    </message>
</context>
<context>
    <name>PlayList</name>
    <message>
        <location filename="../playlist.cpp" line="177"/>
        <source>&amp;Copy Selection To</source>
        <translation>&amp;Kopijuoti pasirinkimą į</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="204"/>
        <source>Sort List</source>
        <translation>Rūšiuoti</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="207"/>
        <location filename="../playlist.cpp" line="242"/>
        <source>By Title</source>
        <translation>Pagal dainos pavadinimą</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="211"/>
        <location filename="../playlist.cpp" line="246"/>
        <source>By Album</source>
        <translation>Pagal albumą</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="215"/>
        <location filename="../playlist.cpp" line="250"/>
        <source>By Artist</source>
        <translation>Pagal atlikėją</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="219"/>
        <location filename="../playlist.cpp" line="254"/>
        <source>By Filename</source>
        <translation>Pagal bylos pavadinimą</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="223"/>
        <location filename="../playlist.cpp" line="258"/>
        <source>By Path + Filename</source>
        <translation>Pagal kelią iki bylos</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="227"/>
        <location filename="../playlist.cpp" line="262"/>
        <source>By Date</source>
        <translation>Pagal datą</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="239"/>
        <source>Sort Selection</source>
        <translation>Rūšiuoti pasirinktus</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="274"/>
        <source>Randomize List</source>
        <translation>Sumaišyti sąrašą</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="276"/>
        <source>Reverse List</source>
        <translation>Apversti</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="550"/>
        <source>&amp;New PlayList</source>
        <translation>&amp;Naujas grojaraštis</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="231"/>
        <location filename="../playlist.cpp" line="266"/>
        <source>By Track Number</source>
        <translation>Pagal takelio numerį</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="53"/>
        <source>Playlist</source>
        <translation>Grojaraštis</translation>
    </message>
    <message>
        <location filename="../playlist.cpp" line="283"/>
        <source>Actions</source>
        <translation>Veiksmai</translation>
    </message>
</context>
<context>
    <name>PlayListBrowser</name>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="14"/>
        <source>Playlist Browser</source>
        <translation>Grojaraščių naršyklė</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="45"/>
        <source>New</source>
        <translation>Naujas</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="52"/>
        <location filename="../playlistbrowser.cpp" line="39"/>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../forms/playlistbrowser.ui" line="69"/>
        <location filename="../forms/playlistbrowser.ui" line="79"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../playlistbrowser.cpp" line="38"/>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
</context>
<context>
    <name>PlayListSelector</name>
    <message>
        <location filename="../playlistselector.cpp" line="51"/>
        <source>&amp;Load</source>
        <translation>&amp;Įkelti</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="52"/>
        <source>&amp;Save As...</source>
        <translation>&amp;Įrašyti kaip...</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="54"/>
        <source>Rename</source>
        <translation>Pervadinti</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="55"/>
        <source>&amp;Delete</source>
        <translation>&amp;Ištrinti</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Rename Playlist</source>
        <translation>Pervadinti grojaraštį</translation>
    </message>
    <message>
        <location filename="../playlistselector.cpp" line="112"/>
        <source>Playlist name:</source>
        <translation>Grojaraščio pavadinimas</translation>
    </message>
</context>
<context>
    <name>PopupSettings</name>
    <message>
        <location filename="../forms/popupsettings.ui" line="14"/>
        <source>Popup Information Settings</source>
        <translation>Iššokančios informacijos nustatymai</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="75"/>
        <source>Show cover</source>
        <translation>Rodyti viršelį</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="115"/>
        <source>Transparency:</source>
        <translation>Permatomumas</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="145"/>
        <source>Delay:</source>
        <translation>Atidėjimas:</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="178"/>
        <source>ms</source>
        <translation>ms</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="89"/>
        <source>Cover size:</source>
        <translation>Nuotraukos dydis</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="29"/>
        <source>Template</source>
        <translation>Šablonas</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="58"/>
        <source>Reset</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../forms/popupsettings.ui" line="65"/>
        <source>Insert</source>
        <translation>Įtraukti</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="62"/>
        <source>Artist</source>
        <translation>Atlikėjas</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="63"/>
        <source>Album</source>
        <translation>Albumas</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="64"/>
        <source>Title</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="65"/>
        <source>Track number</source>
        <translation>Takelio numeris</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="66"/>
        <source>Two-digit track number</source>
        <translation>Dviejų skaičių takelio numeris</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="67"/>
        <source>Genre</source>
        <translation>Žanras</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="68"/>
        <source>Comment</source>
        <translation>Komentaras</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="69"/>
        <source>Composer</source>
        <translation>Autorius</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="70"/>
        <source>Duration</source>
        <translation>Ilgis</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="71"/>
        <source>Disc number</source>
        <translation>Disko numeris</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="72"/>
        <source>File name</source>
        <translation>Bylos pavadinimas</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="73"/>
        <source>File path</source>
        <translation>Bylos kelias</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="74"/>
        <source>Year</source>
        <translation>Metai</translation>
    </message>
    <message>
        <location filename="../popupsettings.cpp" line="75"/>
        <source>Condition</source>
        <translation>Būklė</translation>
    </message>
</context>
<context>
    <name>PresetEditor</name>
    <message>
        <location filename="../forms/preseteditor.ui" line="14"/>
        <source>Preset Editor</source>
        <translation>Nustatymų redaktorius</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="77"/>
        <source>Load</source>
        <translation>Įkelti</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="84"/>
        <source>Delete</source>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="36"/>
        <source>Preset</source>
        <translation>Nustatymas</translation>
    </message>
    <message>
        <location filename="../forms/preseteditor.ui" line="52"/>
        <source>Auto-preset</source>
        <translation>Auto-nustatymas</translation>
    </message>
</context>
<context>
    <name>QMMPStarter</name>
    <message>
        <location filename="../qmmpstarter.cpp" line="176"/>
        <source>Usage: qmmp [options] [files]</source>
        <translation>Naudojimas: qmmp [nuostatos] [bylos]</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="177"/>
        <source>Options:</source>
        <translation>Nustatymai:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="183"/>
        <source>Print version number and exit</source>
        <translation>Parodyti versiją ir išeiti</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="182"/>
        <source>Display this text and exit</source>
        <translation>Parodyti šį tekstą ir išeiti</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="71"/>
        <source>Unknown command</source>
        <translation>Nežinoma komanda</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="181"/>
        <source>Don&apos;t start the application</source>
        <translation>Nepaleisti programos</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="184"/>
        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
        <translation>Idėjas, pataisymus, klaidas siųsti forkotov02@hotmail.ru</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="189"/>
        <source>QMMP version:</source>
        <translation>QMMP versija:</translation>
    </message>
    <message>
        <location filename="../qmmpstarter.cpp" line="190"/>
        <source>Qt version:</source>
        <translation>Qt versija:</translation>
    </message>
</context>
<context>
    <name>ShortcutDialog</name>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="14"/>
        <source>Change Shortcut</source>
        <translation>Keisti trumpinį</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="29"/>
        <source>Press the key combination you want to assign</source>
        <translation>Paspauskite klavišų kombinaciją, kurią norite priskirti</translation>
    </message>
    <message>
        <location filename="../forms/shortcutdialog.ui" line="43"/>
        <source>Clear</source>
        <translation>Išvalyti</translation>
    </message>
</context>
<context>
    <name>TextScroller</name>
    <message>
        <location filename="../textscroller.cpp" line="53"/>
        <source>Autoscroll Songname</source>
        <translation>Automatinis takelio slinkimas</translation>
    </message>
    <message>
        <location filename="../textscroller.cpp" line="118"/>
        <source>Buffering: %1%</source>
        <translation>Buferis: %1%</translation>
    </message>
</context>
<context>
    <name>VisualMenu</name>
    <message>
        <location filename="../visualmenu.cpp" line="29"/>
        <source>Visualization</source>
        <translation>Vizualizacija</translation>
    </message>
</context>
</TS>
